@@ -15,7 +15,6 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Dict, Tuple
 
 import tensorflow as tf
 
@@ -37,7 +36,7 @@ class Dataset:
 
     def __post_init__(self) -> None:
         """
-        :raise ValueError (or InvalidArgumentError): If ``query_points`` or ``observations`` have
+        :raise ValueError (or InvalidArgumentError): If ``query_points`` or ``observations`` have \
             rank less than two, or they have unequal shape in any but their last dimension.
         """
         tf.debugging.assert_rank_at_least(self.query_points, 2)
@@ -94,10 +93,10 @@ class Dataset:
         """
         return tf.shape(self.observations)[0]
 
-    def __deepcopy__(self, memo: Dict[int, object]) -> Dataset:
+    def __deepcopy__(self, memo: dict[int, object]) -> Dataset:
         return self
 
-    def astuple(self) -> Tuple[TensorType, TensorType]:
+    def astuple(self) -> tuple[TensorType, TensorType]:
         """
         **Note:** Unlike the standard library function `dataclasses.astuple`, this method does
         **not** deepcopy the attributes.
